@@ -23,7 +23,7 @@ class RobotFactory(object):
                 }]
             }
             _code = 0
-            res = requests.post(self.url + self.key, headers=self.headers, data=json.dumps(message), timeout=10)
+            res = requests.post(self.url + self.token, headers=self.headers, data=json.dumps(message), timeout=10)
             if res.status_code == 200:
                 return _code
         except Exception as e:
